
{% extends 'admin/base.html' %}

{% load i18n static %}


{% block extrastyle %}
    <link href='{% static "cap/components/bootstrap/bootstrap.min.css" %}' rel='stylesheet' type='text/css'>
    <link href='{% static "cap/components/jquery-ui/jquery-ui.min.css" %}' rel='stylesheet' type='text/css'>
    <link href='{% static "cap/components/font-awesome/font-awesome.min.css" %}' rel='stylesheet' type='text/css'>
    <link href='{% static "cap/components/qtip2/jquery.qtip.min.css" %}' rel='stylesheet' type='text/css'>
    <link href='{% static "cap/components/fancybox/jquery.fancybox.min.css" %}' rel='stylesheet' type='text/css'>
    <link href='{% static "cap/components/bootstrap-treeview/bootstrap-treeview.min.css" %}' rel='stylesheet' type='text/css'>
    <link href='{% static "cap/components/bootstrap-tagsinput/bootstrap-tagsinput.css" %}' rel='stylesheet' type='text/css'>
{% endblock %}


{% block footer %}
    <script src="{% static "cap/components/jquery.min.js" %}"></script>
    <script src="{% static "cap/components/jquery-ui/jquery-ui.min.js" %}"></script>
    <script src="{{ STATIC_URL }}cap/components/jquery-ui/i18n/{{ LANGUAGE_CODE }}.js"></script>
    <script src="{% static "cap/components/jquery.form.min.js" %}"></script>
    <script src="{% static "cap/components/bootstrap/bootstrap.min.js" %}"></script>
    <script src="{% static "cap/components/bootstrap-treeview/bootstrap-treeview.min.js" %}"></script>
    <script src="{% static "cap/components/fancybox/jquery.fancybox.min.js" %}"></script>
    <script src="{% static "cap/components/qtip2/jquery.qtip.min.js" %}"></script>
    <script src="{{ STATIC_URL }}cap/components/bootstrap-tagsinput/bootstrap-tagsinput.js"></script>
    <script src="{{ STATIC_URL }}jquery/ajax-csrf.js"></script>

    <script>
        $(function() {
            $("[data-role=datepicker]").datepicker({
                dateFormat: 'dd/mm/yy'
            });
        });
    </script>
    {{ block.super }}
{% endblock %}